@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Exporter 'import';
 
-our $VERSION = "0.011";
+our $VERSION = "0.02";
 
 our @EXPORT_OK = qw/hash_bulk_keycopy/;
 
@@ -25,7 +25,7 @@ Hash::BulkKeyCopy - a xs module for clone hash with keys
     use Hash::BulkKeyCopy;
 
 =head1 USAGE
-my $ht_ka = ["k1_1", "k1_2", "k1_3"];  
+my $ht_ka = ["k1_1", "k1_2", "k1_3"]; # it will use src_hash's keys when give an empty array  
 my $hs_ka = ["k2_1", "k2_2", "k2_3"];  
     
 my ($h1, $h2) = ({}, {"k2_1" => 1, "k2_2" => undef, "k2_3" => []});  
